@@ -12,8 +12,6 @@ use Config qw/%Config/;
 # The minimum allowed versions of the compilers.
 my $clangmin = 3.9;
 my $gccmin = 4.9;
-# Version regexp matches 1.1.1 etc.
-my $vre = qr!((?:[0-9]+\.)+[0-9]+)!;
 
 sub check_cc_version
 {
@@ -22,11 +20,11 @@ sub check_cc_version
 	die "I cannot find a C compiler in your \%Config";
     }
     my $version = `$cc --version`;
-    if ($version =~ /clang.*?$vre/) {
+    if ($version =~ /clang.*?([0-9.]+)/) {
 	compiler ('clang', $1, $clangmin);
 	return;
     }
-    if ($version =~ /gcc.*?$vre/) {
+    if ($version =~ /gcc.*?([0-9.]+)/) {
 	compiler ('gcc', $1, $gccmin);
 	return;
     }
